@@ -1,7 +1,7 @@
 package baremetal
 
 import (
-	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/human"
 	baremetal "github.com/scaleway/scaleway-sdk-go/api/baremetal/v1"
 )
