@@ -6,13 +6,11 @@ import (
 	"github.com/scaleway/scaleway-sdk-go/api/baremetal/v1"
 )
 
-var (
-	offerAvailabilityMarshalSpecs = human.EnumMarshalSpecs{
-		baremetal.OfferStockEmpty:     &human.EnumMarshalSpec{Attribute: color.FgRed, Value: "empty"},
-		baremetal.OfferStockLow:       &human.EnumMarshalSpec{Attribute: color.FgYellow, Value: "low"},
-		baremetal.OfferStockAvailable: &human.EnumMarshalSpec{Attribute: color.FgGreen, Value: "available"},
-	}
-)
+var offerAvailabilityMarshalSpecs = human.EnumMarshalSpecs{
+	baremetal.OfferStockEmpty:     &human.EnumMarshalSpec{Attribute: color.FgRed, Value: "empty"},
+	baremetal.OfferStockLow:       &human.EnumMarshalSpec{Attribute: color.FgYellow, Value: "low"},
+	baremetal.OfferStockAvailable: &human.EnumMarshalSpec{Attribute: color.FgGreen, Value: "available"},
+}
 
 func listOfferMarshalerFunc(i interface{}, opt *human.MarshalOpt) (string, error) {
 	type tmp baremetal.Offer
@@ -43,8 +41,8 @@ func listOfferMarshalerFunc(i interface{}, opt *human.MarshalOpt) (string, error
 			Title:     "PrivateBandwidth(Mbit/s)",
 		},
 	}
-	baremetalOffer.PrivateBandwidth = baremetalOffer.PrivateBandwidth / 1000000
-	baremetalOffer.Bandwidth = baremetalOffer.Bandwidth / 1000000
+	baremetalOffer.PrivateBandwidth /= 1000000
+	baremetalOffer.Bandwidth /= 1000000
 	str, err := human.Marshal(baremetalOffer, opt)
 	if err != nil {
 		return "", err
