@@ -1,7 +1,7 @@
 package flexibleip
 
 import (
-	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/human"
 	fip "github.com/scaleway/scaleway-sdk-go/api/flexibleip/v1alpha1"
 )
