@@ -6,7 +6,7 @@ import (
 	"os"
 	"testing"
 
-	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	"github.com/scaleway/scaleway-cli/v2/core"
 	function "github.com/scaleway/scaleway-cli/v2/internal/namespaces/function/v1beta1"
 	functionSDK "github.com/scaleway/scaleway-sdk-go/api/function/v1beta1"
 	"github.com/scaleway/scaleway-sdk-go/scw"
