@@ -13,7 +13,7 @@ import (
 	"time"
 
 	"github.com/fatih/color"
-	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/human"
 	"github.com/scaleway/scaleway-cli/v2/internal/interactive"
 	block "github.com/scaleway/scaleway-sdk-go/api/block/v1alpha1"
@@ -67,7 +67,7 @@ func serversMarshalerFunc(i interface{}, opt *human.MarshalOpt) (string, error)
 		PrivateIP         *string
 		Tags              []string
 		ImageName         string
-		RoutedIPEnabled   bool
+		RoutedIPEnabled   *bool
 		PlacementGroup    *instance.PlacementGroup
 		ModificationDate  *time.Time
 		CreationDate      *time.Time
@@ -103,7 +103,7 @@ func serversMarshalerFunc(i interface{}, opt *human.MarshalOpt) (string, error)
 			PrivateIP:         server.PrivateIP,
 			Tags:              server.Tags,
 			ImageName:         serverImageName,
-			RoutedIPEnabled:   server.RoutedIPEnabled,
+			RoutedIPEnabled:   server.RoutedIPEnabled, //nolint: staticcheck // Field is deprecated but still supported
 			PlacementGroup:    server.PlacementGroup,
 			ModificationDate:  server.ModificationDate,
 			CreationDate:      server.CreationDate,
