@@ -4,7 +4,7 @@ import (
 	"testing"
 
 	"github.com/alecthomas/assert"
-	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/interactive"
 	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/instance/v1"
 	instanceSDK "github.com/scaleway/scaleway-sdk-go/api/instance/v1"
@@ -157,7 +157,7 @@ func Test_ServerEnableRoutedIP(t *testing.T) {
 					ServerID: storedServer.ID,
 				})
 				assert.Nil(t, err)
-				assert.Equal(t, true, server.Server.RoutedIPEnabled)
+				assert.Equal(t, scw.BoolPtr(true), server.Server.RoutedIPEnabled) //nolint: staticcheck // Field is deprecated but tested
 				ip, err := api.GetIP(&instanceSDK.GetIPRequest{
 					Zone: storedServer.Zone,
 					IP:   storedServer.PublicIP.ID,
